@@ -6,6 +6,7 @@ use crate::clarity::types::{PrincipalData, QualifiedContractIdentifier, TraitIde
 use crate::clarity::{ClarityName, SymbolicExpression, SymbolicExpressionType};
 use std::collections::HashMap;
 
+#[derive(Clone)]
 pub struct TypedVar<'a> {
     pub name: &'a ClarityName,
     pub type_expr: &'a SymbolicExpression,
@@ -733,7 +734,8 @@ pub trait ASTVisitor<'a> {
         then_expr: &'a SymbolicExpression,
         else_expr: &'a SymbolicExpression,
     ) -> bool {
-        self.traverse_expr(then_expr)
+        self.traverse_expr(cond)
+            && self.traverse_expr(then_expr)
             && self.traverse_expr(else_expr)
             && self.visit_if(expr, cond, then_expr, else_expr)
     }
