@@ -221,7 +221,13 @@ mod tests {
 )
 "
         .to_string();
-        match session.formatted_interpretation(snippet, Some("checker".to_string()), false, None) {
+        match session.formatted_interpretation(
+            snippet,
+            Some("checker".to_string()),
+            false,
+            false,
+            None,
+        ) {
             Err(output) => {
                 assert_eq!(output.len(), 3);
                 assert_eq!(
@@ -251,7 +257,13 @@ mod tests {
 )
 "
         .to_string();
-        match session.formatted_interpretation(snippet, Some("checker".to_string()), false, None) {
+        match session.formatted_interpretation(
+            snippet,
+            Some("checker".to_string()),
+            false,
+            false,
+            None,
+        ) {
             Err(output) => {
                 assert_eq!(output.len(), 3);
                 assert_eq!(
@@ -281,7 +293,13 @@ mod tests {
 )
 "
         .to_string();
-        match session.formatted_interpretation(snippet, Some("checker".to_string()), false, None) {
+        match session.formatted_interpretation(
+            snippet,
+            Some("checker".to_string()),
+            false,
+            false,
+            None,
+        ) {
             Err(output) => {
                 assert_eq!(output.len(), 3);
                 assert_eq!(
@@ -311,7 +329,13 @@ mod tests {
 )
 "
         .to_string();
-        match session.formatted_interpretation(snippet, Some("checker".to_string()), false, None) {
+        match session.formatted_interpretation(
+            snippet,
+            Some("checker".to_string()),
+            false,
+            false,
+            None,
+        ) {
             Ok((_, result)) => {
                 assert_eq!(result.diagnostics.len(), 0);
             }
@@ -328,9 +352,13 @@ mod tests {
 (define-private (kv-set (key int) (value int))
     (map-set kv-store { key: key } { value: value } {value: 0}))"
             .to_string();
-        if let Err(err_output) =
-            session.formatted_interpretation(snippet, Some("checker".to_string()), false, None)
-        {
+        if let Err(err_output) = session.formatted_interpretation(
+            snippet,
+            Some("checker".to_string()),
+            false,
+            false,
+            None,
+        ) {
             assert_eq!(err_output[0], format!("checker:5:5: {}: incorrect number of arguments in call to 'map-set' (expected 3 got 4)", red!("error")));
         } else {
             panic!("expected error")
@@ -342,9 +370,13 @@ mod tests {
 (define-private (kv-add (key int) (value int))
     (map-insert kv-store { key: key } { value: value } { value: 0}))"
             .to_string();
-        if let Err(err_output) =
-            session.formatted_interpretation(snippet, Some("checker".to_string()), false, None)
-        {
+        if let Err(err_output) = session.formatted_interpretation(
+            snippet,
+            Some("checker".to_string()),
+            false,
+            false,
+            None,
+        ) {
             assert_eq!(err_output[0], format!("checker:5:5: {}: incorrect number of arguments in call to 'map-insert' (expected 3 got 4)", red!("error")));
         } else {
             panic!("expected error")
@@ -356,9 +388,13 @@ mod tests {
 (define-private (kv-del (key int))
     (map-delete kv-store { key: 1 } {value: 0}))"
             .to_string();
-        if let Err(err_output) =
-            session.formatted_interpretation(snippet, Some("checker".to_string()), false, None)
-        {
+        if let Err(err_output) = session.formatted_interpretation(
+            snippet,
+            Some("checker".to_string()),
+            false,
+            false,
+            None,
+        ) {
             assert_eq!(err_output[0], format!("checker:5:5: {}: incorrect number of arguments in call to 'map-delete' (expected 2 got 3)", red!("error")));
         } else {
             panic!("expected error")
