@@ -16,6 +16,8 @@ use crate::clarity::database::structures::{
     DataMapMetadata, DataVariableMetadata, FungibleTokenMetadata, NonFungibleTokenMetadata,
 };
 use crate::clarity::database::ClarityDatabase;
+#[cfg(feature = "cli")]
+use crate::clarity::debug::DebugState;
 use crate::clarity::errors::{
     CheckErrors, InterpreterError, InterpreterResult as Result, RuntimeErrorType,
 };
@@ -92,6 +94,8 @@ pub struct GlobalContext<'a> {
     pub mainnet: bool,
     pub coverage_reporting: Option<TestCoverageReport>,
     pub costs_reporting: Option<CostsReport>,
+    #[cfg(feature = "cli")]
+    pub debug_state: Option<DebugState>,
 }
 
 #[derive(Serialize, Deserialize, Clone)]
@@ -1198,6 +1202,8 @@ impl<'a> GlobalContext<'a> {
             mainnet,
             coverage_reporting: None,
             costs_reporting: None,
+            #[cfg(feature = "cli")]
+            debug_state: None,
         }
     }
 
